content
stringlengths
0
1.05M
origin
stringclasses
2 values
type
stringclasses
2 values
-- add modes: debug and release add_rules("mode.debug", "mode.release") -- define target target("${TARGETNAME}") -- set kind set_kind("shared") -- add include dirs add_includedirs("inc") -- generate relocatable device code for device linker of dependents. -- if __device__ or __global__ func...
nilq/small-lua-stack
null
local mod = DBM:NewMod("d589", "DBM-Scenario-MoP") local L = mod:GetLocalizedStrings() mod:SetRevision(("$Revision: 2 $"):sub(12, -3)) mod:SetZone() mod:RegisterCombat("scenario", 1104) mod:RegisterEventsInCombat( "SPELL_AURA_APPLIED", "SPELL_AURA_REMOVED", "UNIT_DIED" ) mod.onlyNormal = true --T...
nilq/small-lua-stack
null
#!/usr/bin/env lua local ui = require "tek.ui" ui.ThemeName = "dark tutorial" ui.UserStyles = false ui.Application:new { Children = { ui.Window:new { Index = 0, updateInterval = function(self) for i = 1, 10 do local n = math.random(1, 28) local e = self:getById("button"..n) e:setValue("Tex...
nilq/small-lua-stack
null
local game = require 'game' return{ name = 'cloudbomb_horizontal', type = 'projectile', friction = 0.01 * game.step, width = 9, height = 9, frameWidth = 9, frameHeight = 9, handle_x = 5, handle_y = 5, solid = true, lift = game.gravity, playerCanPickUp = false, enemyCanPickUp = true, canPlayerStore = false, velocity = {...
nilq/small-lua-stack
null
return function() local Container = script.Parent local App = Container.Parent local UIBlox = App.Parent local Packages = UIBlox.Parent local Roact = require(Packages.Roact) local mockStyleComponent = require(UIBlox.Utility.mockStyleComponent) local VerticalScrollView = require(Container.VerticalScrollView) de...
nilq/small-lua-stack
null
local keywordHandler = KeywordHandler:new() local npcHandler = NpcHandler:new(keywordHandler) NpcSystem.parseParameters(npcHandler) function onCreatureAppear(cid) npcHandler:onCreatureAppear(cid) end function onCreatureDisappear(cid) npcHandler:onCreatureDisappear(cid) end function onCreatureSay(cid, type, msg)...
nilq/small-lua-stack
null
hook.Add("Initialize", "AttachmentVendorOverride", function() if (ATTACHMENT_VENDOR.override.enable != true) then return; end // CW2 if (istable(CustomizableWeaponry)) then ATTACHMENT_VENDOR.override.CWGiveAttachments = CustomizableWeaponry.giveAttachments; CustomizableWeaponry.giveAttachments ...
nilq/small-lua-stack
null
local AddonName, AddonTable = ... AddonTable.trade = { -- Meat/Fish 124117, 124119, 124120, 124121, 142336, -- General 136342, 124124, 151568, -- Misc 18365, }
nilq/small-lua-stack
null
local Command = {} Command.cmd = function(commands) for _, value in ipairs(commands) do vim.cmd(value) end end return Command
nilq/small-lua-stack
null
WireToolSetup.setCategory( "Vehicle Control", "Visuals" ) WireToolSetup.open( "cam", "Cam Controller", "gmod_wire_cameracontroller", nil, "Cam Controllers" ) if ( CLIENT ) then language.Add( "Tool.wire_cam.name", "Cam Controller Tool (Wire)" ) language.Add( "Tool.wire_cam.desc", "Spawns a constant Cam Controller pro...
nilq/small-lua-stack
null
local Collection = require(script.Collection) local PureCollection = require(script.PureCollection) local Registry = require(script.Registry) return { Collection = Collection, PureCollection = PureCollection, Registry = Registry, }
nilq/small-lua-stack
null
--[[ Copyright (c) 2018, Vsevolod Stakhov <vsevolod@highsecure.ru> Copyright (c) 2019, Carsten Rosenberg <c.rosenberg@heinlein-support.de> Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http:/...
nilq/small-lua-stack
null
pg = pg or {} pg.enemy_data_statistics_52 = { [805200] = { cannon = 394, reload = 150, speed_growth = 0, cannon_growth = 0, rarity = 3, air = 0, torpedo = 742, dodge = 100, durability_growth = 0, antiaircraft = 235, luck = 0, reload_growth = 0, dodge_growth = 0, hit_growth = 0, star = 4, ...
nilq/small-lua-stack
null
SetupExternalManagedProject("CppSharp.Parser.Gen")
nilq/small-lua-stack
null
--item-group if data.raw["item-group"]["bob-logistics"] then data.raw["item-group"]["bob-logistics"].icon = "__morebobs_shiny__/graphics/category/electronics-machine-chip.png" end if data.raw["item-group"]["bob-logistics"] then data.raw["item-group"]["bob-logistics"].icon_size = 128 end if data.raw["item-group"]["bo...
nilq/small-lua-stack
null
local api = vim.api local luv = vim.loop local renderer = require'nvim-tree.renderer' local config = require'nvim-tree.config' local git = require'nvim-tree.git' local diagnostics = require'nvim-tree.diagnostics' local pops = require'nvim-tree.populate' local utils = require'nvim-tree.utils' local view = require'nvim-...
nilq/small-lua-stack
null
object_tangible_holiday_empire_day_remembrance_day_rebel_banner = object_tangible_holiday_empire_day_shared_remembrance_day_rebel_banner:new { } ObjectTemplates:addTemplate(object_tangible_holiday_empire_day_remembrance_day_rebel_banner, "object/tangible/holiday/empire_day/remembrance_day_rebel_banner.iff")
nilq/small-lua-stack
null
--[[ Snapper: to generate delta stats based on specific period. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Script template can be either Lua or JSON format, elements: Mandatory: sql: can be a SQL string, or an array that in Lua/Json format, refer to command 'grid' for more de...
nilq/small-lua-stack
null
--region BaseView.lua --Date 2019/03/30 --Author NormanYang --View 层基类 --endregion local setmetatable = setmetatable local wait = coroutine.wait BaseView = {} local this = BaseView; this.__index = this; --创建View对象-- function BaseView:New(bundleName, atlasName) return setmetatable({bundleName = bundleName, atlasNa...
nilq/small-lua-stack
null
jilljoo_jab_missions = { { missionType = "escort", primarySpawns = { { npcTemplate = "jilljoo_slave", npcName = "Sadelli" } }, secondarySpawns = { { npcTemplate = "thug", npcName = "a Thug" }, { npcTemplate = "thug", npcName = "a Thug" }, }, itemSpawns = {}, rewards = { ...
nilq/small-lua-stack
null
function _G.q(...) local objects = vim.tbl_map(vim.inspect, {...}) print(unpack(objects)) return ... end vim.cmd[[command! -nargs=1 -complete=lua Q lua q(<args>)]] function _G.t(str) return vim.api.nvim_replace_termcodes(str, true, true, true) end --- Jump to the next entry in the jumplist which is a child of...
nilq/small-lua-stack
null
object_mobile_npe_dressed_rakqua_shaman_02 = object_mobile_npe_shared_dressed_rakqua_shaman_02:new { } ObjectTemplates:addTemplate(object_mobile_npe_dressed_rakqua_shaman_02, "object/mobile/npe/dressed_rakqua_shaman_02.iff")
nilq/small-lua-stack
null
SCHEMA.name = "Military RP (WIP)" SCHEMA.introname = "Military RP (WIP)" SCHEMA.author = "ChazNN" SCHEMA.desc = "A Serious Military RP" function SCHEMA:isArmyFaction(faction) return faction == FACTION_ARMY or faction == FACTION_ARMYCOMMAND end function SCHEMA:isNavyFaction(faction) return faction == FACTION_NAVY or...
nilq/small-lua-stack
null
-- Prosody IM -- Copyright (C) 2008-2010 Matthew Wild -- Copyright (C) 2008-2010 Waqas Hussain -- -- This project is MIT/X11 licensed. Please see the -- COPYING file in the source package for more information. -- local allow_registration = module:get_option_boolean("allow_registration", false); if allow_registration...
nilq/small-lua-stack
null
local Class = require "lib.hump.Class" local Component = require "component.Component" local Signals = require "constants.Signals" local HPComponent = Class{} HPComponent:include(Component) function HPComponent:init(hp, hitSignal) assert(hp and hitSignal, "arguments missing") Component.init(self) self.type = "...
nilq/small-lua-stack
null
local path = debug.getinfo(1).short_src:match("([^%.]*)[\\/][^%.]*%..*$"):gsub("[\\/]", ".") .. "." local engine = require(path .. "core") function love.run() engine:init() local engine_event = engine.event love.graphics.setFont(love.graphics.newFont()) love.handlers = setmetatable({ keypressed = function(b, u...
nilq/small-lua-stack
null
-- Nvim-tree Configuration local mapping_config = require "jesse.mapping.plugin.nvim-tree" require("nvim-tree").setup { disable_netrw = true, hijack_netrw = true, hijack_cursor = true, view = { auto_resize = true, mappings = { list = mapping_config.list, }, }, }
nilq/small-lua-stack
null
local test = {} test['should before of string'] = function() local str1 = "this is a test" local str2 = "this is" assert( str1:mid(1, 7) == str2 ) end test['should middle of string'] = function() local str1 = "this is a test" local str2 = "is a" assert( str1:mid(6, 4) == str2 ) end test['should end of st...
nilq/small-lua-stack
null
print('sleeping 5 mins') node.dsleep(5*60*1000000)
nilq/small-lua-stack
null
function onRecalculateRating() if ratingName == 'Perfect!!' then setRatingName('Cool!!') elseif ratingName == 'Sick!' then setRatingName('Sick!') elseif ratingName == 'Great' then setRatingName('Skill Issue') elseif ratingName == 'Good' then setRatingName('Ratio') elseif ratingName == 'Meh...
nilq/small-lua-stack
null
local BasePlugin = require "kong.plugins.base_plugin" local CustomHandler = BasePlugin:extend() local kong = kong.response local ngx = ngx function CustomHandler:new() CustomHandler.super.new(self, "orgcode") end function CustomHandler:init_worker() CustomHandler.super.init_worker(self) end function CustomHa...
nilq/small-lua-stack
null
include("shared.lua"); -- Called when the entity initializes. function ENT:Initialize() end -- Called when the entity should draw. function ENT:Draw() self.Entity:DrawModel() end -- Called when the entity should think. function ENT:Think() local dlight = DynamicLight( self:EntIndex() ) if ( dlight ) then loc...
nilq/small-lua-stack
null
require 'nn' --require 'cunn' require 'cudnn' --require 'dpnn' --require 'nnx' --local inn = require 'inn' -- if not nn.SpatialConstDiagonal then -- torch.class('nn.SpatialConstDiagonal', 'inn.ConstAffine') -- end --local utils = paths.dofile('modelUtils.lua') --require 'models/DeepMask' local M = {} function M.se...
nilq/small-lua-stack
null
require 'Scripts/premake-defines' require 'Scripts/premake-common' require 'Scripts/premake-triggers' require 'Scripts/premake-settings' --require 'Scripts/premake-vscode/vscode' root_dir = os.getcwd() Arch = "" if _OPTIONS["arch"] then Arch = _OPTIONS["arch"] else if _OPTIONS["os"] then _OPTIONS["arch"] = "arm"...
nilq/small-lua-stack
null
local system = require "system" local mysql = require "mysql" local json = require "rapidjson" local function serialize(obj) local lua = "" local t = type(obj) if t == "number" then lua = lua .. obj elseif t == "boolean" then lua = lua .. tostring(obj) elseif t == "string" then ...
nilq/small-lua-stack
null
--[[ Name: sh_mayor_ss_menu.lua For: TalosLife By: TalosLife ]]-- local App = {} App.Name = "Secret Service" App.ID = "nsa.exe" App.Panel = "SRPComputer_AppWindow_SecretService" App.Icon = "nomad/computer/icon_ss.png" App.DekstopIcon = true App.StartMenuIcon = true --App code --End app code GM.Apps:Register( App )...
nilq/small-lua-stack
null
return Def.ActorFrame { --Def.ControllerStateDisplay { -- InitCommand=function(self) -- self:LoadGameController() --end, --}; Def.DeviceList { Font = "Common Normal", InitCommand = function(self) self:x(SCREEN_LEFT + 20):y(SCREEN_TOP + 80):zoom(0.8):halign(0) end }, Def.InputList { Font = "Common Nor...
nilq/small-lua-stack
null
setenv(myModuleName(),myModuleFullName())
nilq/small-lua-stack
null
--- -- @classmod Color local middleclass = require("middleclass") local typeutils = require("typeutils") --- -- @table instance -- @tfield number red [0, 1] -- @tfield number green [0, 1] -- @tfield number blue [0, 1] local Color = middleclass("Color") --- -- @function new -- @tparam number red [0, 1] -- @tparam nu...
nilq/small-lua-stack
null
-------------------------------------------------------------------------------------- -- this is the ActionPattern class which extends PlanElement -- -- an ActionPattern is an aggregate defined by: -- -- . unique name identifier ...
nilq/small-lua-stack
null
-- -- Licensed to the Apache Software Foundation (ASF) under one or more -- contributor license agreements. See the NOTICE file distributed with -- this work for additional information regarding copyright ownership. -- The ASF licenses this file to You under the Apache License, Version 2.0 -- (the "License"); you may ...
nilq/small-lua-stack
null
-- ============================================================= -- Copyright Roaming Gamer, LLC. 2008-2018 (All Rights Reserved) -- ============================================================= local getTimer = system.getTimer -- == -- fnn( ... ) - Return first argument from list that is not nil. -- ... - Any ...
nilq/small-lua-stack
null
-- Definition of the neural network used to learn entity embeddings. -- To run a simple unit test that checks the forward and backward passes, just run : -- th entities/learn_e2v/model_a.lua if not opt then -- unit tests unit_tests = true dofile 'utils/utils.lua' require 'nn' cmd = torch.CmdLine() cmd:opt...
nilq/small-lua-stack
null
-- Copyright 2021 SmartThings -- -- Licensed under the Apache License, Version 2.0 (the "License"); -- you may not use this file except in compliance with the License. -- You may obtain a copy of the License at -- -- http://www.apache.org/licenses/LICENSE-2.0 -- -- Unless required by applicable law or agreed to in ...
nilq/small-lua-stack
null
object_building_mustafar_structures_must_bandit_fence_16m = object_building_mustafar_structures_shared_must_bandit_fence_16m:new { } ObjectTemplates:addTemplate(object_building_mustafar_structures_must_bandit_fence_16m, "object/building/mustafar/structures/must_bandit_fence_16m.iff")
nilq/small-lua-stack
null
return { entities = { {"electric-mining-drill", {x = 0.5, y = 0.5}, {dir = "west", }}, {"iron-chest", {x = -1.5, y = 0.5}, {items = {["copper-ore"] = {type = "random", min = 1, max = 75}}, }}, }, }
nilq/small-lua-stack
null
local function not_impl() error("Function not implemented"); end local mime = require "mime"; module "encodings" stringprep = {}; base64 = { encode = mime.b64, decode = not_impl }; --mime.unb64 is buggy with \0 return _M;
nilq/small-lua-stack
null
setobjecttype("destructables")
nilq/small-lua-stack
null
--[[ Unit tests for the DBM module of the Lua/APR binding. Author: Peter Odding <peter@peterodding.com> Last Change: June 30, 2011 Homepage: http://peterodding.com/code/lua/apr/ License: MIT --]] local status, apr = pcall(require, 'apr') if not status then pcall(require, 'luarocks.require') apr = require '...
nilq/small-lua-stack
null
//----------------------------------------------------------------------------------------------- // //shared file for information revolving the ghoul entity // //@author TotallyNotLuna/luna/StudioNightly //@version 21/4/18 //----------------------------------------------------------------------------------------...
nilq/small-lua-stack
null
local skynet = require "skynet" require "skynet.manager" local httpc = require "http.httpc" local dns = require "dns" local cjson = require "cjson" local function request(host, url, msg) local content = cjson.encode(msg) local header = {} local respheader = {} local status, body = httpc.request("post",...
nilq/small-lua-stack
null
---@class hmultiBoard 多面板/多列榜 hmultiBoard = {} --- 根据玩家创建多面板 --- 多面板是可以每个玩家看到的都不一样的 --- yourData会返回当前的多面板和玩家索引 --- 你需要设置数据传回到create中来,拼凑多面板数据,二维数组,行列模式 ---@alias hmultiBoard fun(whichBoard: userdata,playerIndex:number):void ---@param key string 多面板唯一key ---@param refreshFrequency number 刷新频率 ---@param yourData hmultiB...
nilq/small-lua-stack
null
local Player = game.Players.LocalPlayer if Player:FindFirstChild("BaseDataLoaded") then script.Parent:Destroy() else local module = require(script.Parent.LoadGuiScript) script.Parent.Contents.Visible = true module.init() end
nilq/small-lua-stack
null
local customize_layout = {} customize_layout.initialize_custom_layout = function () local screen = mouse.screen screen.tags[1].master_width_factor = 0.20 screen.tags[2].master_width_factor = 0.20 screen.tags[1]:view_only() -- To set a layout per tag: -- screen.tags[2].layout = awful.layout.suit.tile.bott...
nilq/small-lua-stack
null
-- 22.01.13 Changed texture to that of the wood from the minimal development game local S = cottages.S minetest.register_node("cottages:fence_small", { description = S("small fence"), drawtype = "nodebox", -- top, bottom, side1, side2, inner, outer tiles = {"cottages_minimal_wood.png"}, paramt...
nilq/small-lua-stack
null
local torchxtest = {} local precision_forward = 1e-6 local precision_backward = 1e-6 local nloop = 50 local mytester --e.g. usage: th -ltorchx -e "torchx.test{'treemax','find'}" function torchxtest.treemax() local treeSize = {3,3,2} -- 13,14,25 18 = 3x3x2 -- 6,7,12 6 = 3x2 -- ...
nilq/small-lua-stack
null
// Generated by github.com/davyxu/tabtoy // Version: 2.8.10 module table { export var TMapEventRefresh : table.ITMapEventRefreshDefine[] = [ { Id : 1, TypeRand : [ "1001-500", "1002-500", "1003-500", "2001-500", "2002-500", "3001-100", "3002-100" ], RangeMin : 0, RangeMax : 1000, Num : 3 }, { Id : 2, TypeRand : [...
nilq/small-lua-stack
null
--[[ Copyright (c) 2016 Technicolor Delivery Technologies, SAS The source code form of this Transformer component is subject to the terms of the Clear BSD license. You can redistribute it and/or modify it under the terms of the Clear BSD License (http://directory.fsf.org/wiki/License:ClearBSD) See LICENSE file for m...
nilq/small-lua-stack
null
local r = game:service("RunService"); function rv() return 5*math.random()-2.5; end function spawn(spawnTime) local droplet = Instance.new("Part") local headPos = game.Workspace.coffeelord:findFirstChild("Head").Position droplet.Position = Vector3.new(headPos.x, headPos.y-5, headPos.z) droplet.Size = Vector...
nilq/small-lua-stack
null
require "module.EtSocket"
nilq/small-lua-stack
null
local Dropout, Parent = torch.class('nn.Dropout', 'nn.Module') function Dropout:__init(p,v1,inplace) Parent.__init(self) self.p = p or 0.5 self.train = true self.inplace = inplace -- version 2 scales output during training instead of evaluation self.v2 = not v1 if self.p >= 1 or self.p < 0 then ...
nilq/small-lua-stack
null
-- If you're not sure your plugin is executing, uncomment the line below and restart Kong -- then it will throw an error which indicates the plugin is being loaded at least. --assert(ngx.get_phase() == "timer", "The world is coming to an end!") -- Grab pluginname from module name local plugin_name = ({...})[1]:match...
nilq/small-lua-stack
null
-- mod-version:2 -- lite-xl 2.0 local syntax = require "core.syntax" syntax.add { name = "Go", files = { "%.go$" }, comment = "//", patterns = { { pattern = "//.-\n", type = "comment" }, { pattern = { "/%*", "%*/" }, type = "comment" }, { pattern = { ...
nilq/small-lua-stack
null
-- ####################################### -- ## Project: HUD iLife ## -- ## For MTA: San Andreas ## -- ## Name: HudComponent_Scoreboard.lua ## -- ## Author: Noneatme ## -- ## Version: 1.0 ## -- ## License: See top Folder ## -- ####################################### -- FUNCTIONS / METHODS -- l...
nilq/small-lua-stack
null
SonLPC=UGen:new{name="SonLPC"} function SonLPC.ar(buff,inp,hop,poles) buff = buff or -1;inp = inp or 0;hop = hop or 0.5;poles = poles or 4 return SonLPC:MultiNew{2,buff,inp,hop,poles} end SonLPCSynth=UGen:new{name="SonLPCSynth"} function SonLPCSynth.ar(chain) chain = chain or -1; return SonLPCSynth:MultiNew{2,chai...
nilq/small-lua-stack
null
-- file: food.lua Food = Object.extend(Object) --- Constructor of a Food class ---@param position table function Food:new(position) self.position = position end --- Execute routines relationed the food elements by transition into frames ---@param dt any function Food:update(dt) end --- Draw elements like a sna...
nilq/small-lua-stack
null
local utils = {} local Log = require "core.log" local uv = vim.loop local api = vim.api -- recursive Print (structure, limit, separator) local function r_inspect_settings(structure, limit, separator) limit = limit or 100 -- default item limit separator = separator or "." -- indent string if limit < 1 then pr...
nilq/small-lua-stack
null
------------------------------------------------------------------------------- -- - Vimwiki API - -- Represents module for accessing vimwiki specific functions for easier -- creation of vimwiki reviews ------------------------------------------------------------------------------- local M = {} -- Normalizes...
nilq/small-lua-stack
null
local SPAWNOBJECT = script:GetCustomProperty("SPAWNOBJECT") local IMPACTSOUND = script:GetCustomProperty("IMPACTSOUND") local WEAPON = script:FindAncestorByType('Weapon') if not WEAPON:IsA('Weapon') then error(script.name .. " should be part of Weapon object hierarchy.") end function Complete( impactTransform ) ...
nilq/small-lua-stack
null
local integrations = {} for _, v in pairs(script:GetChildren()) do integrations[v.Name] = require(v) end return integrations
nilq/small-lua-stack
null
local uv = require "lluv" uv.timer():start(100, function() error('SOME_ERROR_MESSAGE') end) local pass = false uv.run(function(msg) print('ERROR MESSAGE:') print(msg) print("-------------------") pass = not not string.find(msg, 'SOME_ERROR_MESSAGE', nil, true) end) if not pass then print('Fail!') os.exit(-1) ...
nilq/small-lua-stack
null
----------------------------------- -- Area: Ship bound for Selbina -- NPC: Rajmonda -- Type: Guild Merchant: Fishing Guild -- !pos 1.841 -2.101 -9.000 220 ----------------------------------- require("scripts/globals/settings") require("scripts/globals/shop") local ID = require("scripts/zones/Ship_bound_for_Selbina/ID...
nilq/small-lua-stack
null
AddCSLuaFile("cl_init.lua") AddCSLuaFile("shared.lua") include("shared.lua") function ENT.Initialize(self) self:SetModel("models/props_wasteland/laundry_cart002.mdl") self:SetUseType(SIMPLE_USE) self:PhysicsInit(SOLID_VPHYSICS) self:SetMoveType(MOVETYPE_VPHYSICS) self:SetSolid(SOLID_VPHYSICS) self.cooldown = 0...
nilq/small-lua-stack
null
--- Decoder must take in a image and return a message local adversarialModel = nn.Sequential() --- input dimension batchsize * 3 * 32 * 32 local ConvBNReLU = dofile('./ConvBNReLU.lua') -- ConvBNReLU(adversarialModel, 3, opt.messageLength) if opt.small or opt.grayscale then ConvBNReLU(adversarialModel, 1, opt.adversar...
nilq/small-lua-stack
null
require "ISUI/ISUIElement" ---@class ISPanelJoypad : ISUIElement ISPanelJoypad = ISUIElement:derive("ISPanelJoypad"); --************************************************************************-- --** ISPanelJoypad:initialise --** --************************************************************************-- function I...
nilq/small-lua-stack
null
-- get all Dependencies require 'src/Dependencies' --Love Function Load function love.load() --Fonts bebasFont = love.graphics.newFont('fonts/BebasNeue-Regular.ttf', 40) gSounds = { ['BulletShoot'] = love.audio.newSource('Sounds/BulletShoot.wav', 'static') } gImages = { ['targetPng']...
nilq/small-lua-stack
null
--[[ ItemSystems.ItemThemes ================ The Customizable properties of the Item System. You can modify item themes and sounds from the ItemTypes or ItemThemes folder in the ItemRegistry folder located in the hierarchy. ]] local Item = script:GetCustomProperty("Item") local ITEM_THEME_FOLDER ...
nilq/small-lua-stack
null
resource_manifest_version '44febabe-d386-4d18-afbe-5e627f4af937' files{ 'index.html', 'css/style.css', 'img/cursor.png', 'img/MyLogo.png', 'img/fondo.jpg', 'fonts/Anton-Regular.ttf', 'js/cursor.js', 'media/audio.mp3' } loadscreen 'index.html' author 'Nekix' description 'SAX = Mala cal...
nilq/small-lua-stack
null
EMVU.AddCustomSiren("nypdssr", { Name = "NYPD Smart Siren Rumbler", -- The name that shows on the HUD. Category = "Other", -- The category the siren shows up under. Set = { {Name = "WAIL", Sound = "emv/sirens/nypd_smartsiren_rumbler/emv_wail.wav", Icon="wail"}, {Name = "YELP", Sound = "emv/sirens/nypd_smartsi...
nilq/small-lua-stack
null
-- initialize all player-related globals function setup_global() global.player_data = global.player_data or {} for i,_ in pairs(game.players) do if not global.player_data[i] then global.player_data[i] = create_player_data(i) end end end -- when a new player first joins the game, c...
nilq/small-lua-stack
null
inventory = {} function inventory:init() inventory.pieces = {} for i = 1, 1 do table.insert(inventory.pieces, piece:new(0, 0, piece.types[love.math.random(5)+1], "white", love.math.random(9), love.math.random(3)-1)) end end --not meant to be executed every frame, only when needed function inventory:update(...
nilq/small-lua-stack
null
local complex = { r= 3, i= 5 } local mti = { __tostring = function( n ) return n.r.."+".. n.i.."i" end, __len = function( n ) return math.sqrt(n.r*n.r + n.i * n.i) end } setmetatable( complex, mti ) print( tostring(complex ) ) print( #complex )
nilq/small-lua-stack
null
-- Use of this source code is governed by the Apache 2.0 license; see COPYING. module(...,package.seeall) -- Implementation of IPsec ESP using AES-GCM with 16 byte ICV and -- “Extended Sequence Numbers” (see RFC 4303 and RFC 4106). Provides -- address-family independent encapsulation/decapsulation routines for -- “tu...
nilq/small-lua-stack
null
--[[ Copyright (c) 2011-2012 qeeplay.com http://dualface.github.com/quick-cocos2d-x/ Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights ...
nilq/small-lua-stack
null
function onKill(creature, target) local targetMonster = target:getMonster() if not targetMonster then return true end if targetMonster:getName():lower() ~= 'ungreez' then return true end local player = creature:getPlayer() if player:getStorageValue(Storage.TheInquisition.Questline) == 18 then -- The Inqu...
nilq/small-lua-stack
null
local expired_items_metric if minetest.get_modpath("monitoring") then expired_items_metric = monitoring.counter( "pipeworks_expired_items_count", "Number of expired items" ) end local function cleanup() local now = os.time() for _, entity in pairs(pipeworks.luaentity.entities) do if not entity.ctime then --...
nilq/small-lua-stack
null
UI = { help = false, messageTimer = 0, message = nil, } function UI.init() end function UI.update(dt) local sy = math.floor((WINDOW_H-300)/2) local sx = math.floor(WINDOW_W/2) love.graphics.setFont(font_title) suit.Label("Sprit3r", sx-100, sy, 200) love.graphics...
nilq/small-lua-stack
null
----------------------------------- -- Area: The Shrine of Ru'Avitau -- Mob: Seiryu (Pet version) ----------------------------------- require("scripts/globals/status"); ----------------------------------- function onMonsterMagicPrepare(mob,target) if (mob:hasStatusEffect(tpz.effect.HUNDRED_FISTS,0) == false) then...
nilq/small-lua-stack
null
local skynet = require "skynet" require "skynet.manager" local table = table local assert = assert local math_fmod = math.fmod local function launch_slave(conf) local command_handler if conf.name == "db_slave_offline" then conf.dirtyagent = nil command_handler = conf.offlineagent.command_handler elseif conf.nam...
nilq/small-lua-stack
null
local class = require("heart.class") local M = class.newClass() function M:init(game, config) self.game = assert(game) self.physicsDomain = assert(self.game.domains.physics) self.boneComponents = assert(self.game.componentManagers.bone) end function M:createComponent(entityId, config) local transform = self....
nilq/small-lua-stack
null
local M = {} local vim = vim local api = require('findr/api') local utils = require('findr/utils') local view = require('findr/view') local model = require('findr/model') local sources = require('findr/sources') local user_io = require('findr/controller/user_io') local maps = require('findr/controller/maps') local ...
nilq/small-lua-stack
null
--[[ Info.lua --]] return { appName = "Collection Agent", author = "Rob Cole", authorsWebsite = "www.robcole.com", donateUrl = "http://www.robcole.com/Rob/Donate", platforms = { 'Windows', 'Mac' }, pluginId = "com.robcole.lightroom.CollectionAgent", xmlRpcUrl = "http://www.robcole.c...
nilq/small-lua-stack
null
--[[ ******************************************************************************** Project owner: RageQuit community Project name: GTW-RPG Developers: Mr_Moose Source code: https://github.com/404rq/GTW-RPG/ Bugtracker: https://discuss.404rq.com/t/issues Suggestions: https://discuss.404rq.com/t/deve...
nilq/small-lua-stack
null
--[[ UI面板类型的枚举 enum_PanelName = { [1] = "LoginPanel", [2] = "RegisterPanel" } --]] Unity = CS.UnityEngine; Sockets = CS.System.Net.Sockets; playerData = {} --玩家数据 propsOwned = {}--拥有的道具 shopItem = {} --商店物品 --DG = CS.DG.Tweening.DoTween;
nilq/small-lua-stack
null
------------------------------------------------------------------------------ -- -- This file is part of the Corona game engine. -- For overview and more information on licensing please refer to README.md -- Home page: https://github.com/coronalabs/corona -- Contact: support@coronalabs.com -- -------------------------...
nilq/small-lua-stack
null
project "MFVE" _enginefiledir = "%{wks.location}/mfve/" location(_enginefiledir) uuid(os.uuid()) kind "StaticLib" language "C++" cppdialect "C++17" --staticruntime "on" targetdir(_apptargetdir) objdir(_appobjdir) defines { --# GLFW #-- "GLFW_INCLUDE_VULKAN", ...
nilq/small-lua-stack
null
local function overwrite_setting(setting_type, setting_name, value) -- setting_type: [bool-setting | int-setting | double-setting | string-setting] if data.raw[setting_type] then local s = data.raw[setting_type][setting_name] if s then if setting_type == 'bool-setting' then s.forced_value = va...
nilq/small-lua-stack
null
local time = {} local nf = util.NiceFloat local EVENT = 1 local PRINT = 2 function time:Start() self.start = SysTime() self.finished = nil self.events = {} self.prints = {} return self end function time:Log(event) if not self.start then self:Start() end -- Print later so as to not induce too much blocking...
nilq/small-lua-stack
null
-- Copyright (C) Izio, Inc - All Rights Reserved -- Unauthorized copying of this file, via any medium is strictly prohibited -- Proprietary and confidential -- Written by Romain Billot <romainbillot3009@gmail.com>, Jully 2017 RegisterNetEvent("iWeapons:cbSearchInfos") local weaponPed = {} local weaponsLoaded = false ...
nilq/small-lua-stack
null
-- Contribution by Guy Mc Donald -- adds jpg files to a tree -- dynamically fills subdirectories in the tree require 'iuplua' require 'iupluacontrols' require 'lfs' require "imlua" require "cdlua" require "cdluaim" require "iupluacd" function View(name) local filename = name..".jpg" local image = im.FileImageLoad...
nilq/small-lua-stack
null